@@ -1,29 +1,16 @@
-/******************************************************************************
- *   Copyright (C) 2010 by Johannes Steffen <johannes.steffen@st.ovgu.de>     *
- *   Copyright (C) 2010 by Sebastian Doerner <sebastian@sebastian-doerner.de> *
- *                                                                            *
- *   This program is free software; you can redistribute it and/or modify     *
- *   it under the terms of the GNU General Public License as published by     *
- *   the Free Software Foundation; either version 2 of the License, or        *
- *   (at your option) any later version.                                      *
- *                                                                            *
- *   This program is distributed in the hope that it will be useful,          *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *   GNU General Public License for more details.                             *
- *                                                                            *
- *   You should have received a copy of the GNU General Public License        *
- *   along with this program; if not, write to the                            *
- *   Free Software Foundation, Inc.,                                          *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA               *
- ******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Johannes Steffen <johannes.steffen@st.ovgu.de>
+    SPDX-FileCopyrightText: 2010 Sebastian Doerner <sebastian@sebastian-doerner.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "tagdialog.h"
 #include "gitwrapper.h"
 
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <ktextedit.h>
+#include <KTextEdit>
 
 #include <QCheckBox>
 #include <QComboBox>
@@ -34,6 +21,7 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QDialogButtonBox>
+#include <QRegularExpression>
 
 TagDialog::TagDialog (QWidget* parent ):
     QDialog (parent, Qt::Dialog),
@@ -138,7 +126,7 @@ void TagDialog::setOkButtonState()
       if (tagName.isEmpty()) {
         toolTip = i18nc("@info:tooltip", "You must enter a tag name first.");
       }
-      else if (tagName.contains(QRegExp("\\s"))) {
+      else if (tagName.contains(QRegularExpression("\\s"))) {
         toolTip = i18nc("@info:tooltip", "Tag names may not contain any whitespace.");
       }
       else if (m_tagNames.contains(tagName)) {
